@@ -43,6 +43,14 @@ test_that("gpe_rules_pre gives same results as pre with airquality data", {
 })
 
 
+test_that("function explain gives previous results", {
+  set.seed(42)
+  airq.ens <- pre(Ozone ~ ., data=airquality, ntrees = 10)
+  expl <- explain(airq.ens, newdata = airquality)
+  # save_to_test(expl, "explain")
+  expect_equal(expl, read_to_test("explain"))
+})
+
 test_that("Importance gives previous results with airquality data",{
   set.seed(42)
   airq.ens <- pre(Ozone ~ ., data=airquality, ntrees = 10)
@@ -186,3 +194,20 @@ test_that("`.get_most_sparse_rule` gives the spares of rules", {
     c(`x > 1` = "!(x > 1)", `x > 2` = "!(x > 2)", `x > 3` = "x > 3", 
       `x > 4` = "x > 4"))
 })
+
+
+test_that("`list.rules` gives previous results", {
+  airct <- ctree(Ozone ~ ., data = airquality)
+  rules <- list()
+  rules[[1]] <- list.rules(airct, removecomplements = FALSE, singleconditions = TRUE)
+  rules[[2]] <- list.rules(airct, removecomplements = FALSE, singleconditions = FALSE)
+  rules[[3]] <- list.rules(airct, removecomplements = FALSE, singleconditions = "only")
+  rules[[4]] <- list.rules(airct, singleconditions = TRUE)
+  rules[[5]] <- list.rules(airct, singleconditions = "only")
+  rules[[6]] <- list.rules(airct, removecomplements = FALSE)
+  
+  # save_to_test(rules, "rules")
+  expect_equal(rules, read_to_test("rules"))
+})
+
+
